@@ -25,11 +25,11 @@ Test2::Aggregate - Aggregate tests for increased speed
 
 =head1 VERSION
 
-Version 0.11_2
+Version 0.11_3
 
 =cut
 
-our $VERSION = '0.11_2';
+our $VERSION = '0.11_3';
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,8 @@ you have numerous small tests) and also facilitate group profiling.
 Test files are expected to end in B<.t> and are run as subtests of a single
 aggregate test.
 
-A bit similar, but simpler in concept and execution to C<Test::Aggregate>, which
+A bit similar (mainly in intent) to L<Test::Aggregate>, but no inspiration was
+drawn from the specific module, so simpler in concept and execution, which
 makes it more likely to work with your test suite (especially if you use modern
 tools like Test2). It does not even try to package each test by default, which may
 be good or bad (e.g. redefines), depending on your requirements.
@@ -47,9 +48,10 @@ be good or bad (e.g. redefines), depending on your requirements.
 Generally, the way to use this module is to try to aggregate sets of quick tests
 (e.g. unit tests). Try to iterativelly add tests to the aggregator, dropping those
 that do not work. Trying an entire suite in one go is a bad idea, an incompatible
-test can break the run failing all the subsequent tests. The module can usually
-work with C<Test::More> suites, but will have more issues than when you use the
-more modern C<Test2::Suite> (see notes).
+test can break the run failing all the subsequent tests (especially when doing
+things like globally redefining built-ins etc). The module can usually work with
+L<Test::More> suites, but will have more issues than when you use the more modern
+L<Test2::Suite> (see notes).
 
 =head1 METHODS
  
@@ -73,6 +75,7 @@ more modern C<Test2::Suite> (see notes).
         stats_output  => $stats_output_path,  # optional
         extend_stats  => 0,                   # optional
         test_warnings => 0,                   # optional
+        pre_eval      => $code_to_eval,       # optional
         dry_run       => 0                    # optional
     );
 
@@ -135,13 +138,14 @@ by default.
 
 =item * C<override> (optional)
 
-Pass C<Sub::Override> key/values as a hashref.
+Pass L<Sub::Override> compatible key/values as a hashref.
 
 =item * C<repeat> (optional)
 
 Number of times to repeat the test(s) (default is 1 for a single run). If
-C<repeat> is negative, the tests will repeat until they fail (or produce a
-warning if C<test_warnings> is also set).
+C<repeat> is negative, L<Test2::Plugin::BailOnFail> is required, as the tests
+will repeat until they bail on a failure. It can be combined with C<test_warnings>
+in which case a warning will also cause the test run to end.
 
 =item * C<unique> (optional)
 
@@ -179,6 +183,15 @@ they are generated leave this option disabled.
 Instead of running the tests, will do C<ok($testname)> for each one. Otherwise,
 test order, stats files etc. will be produced normally.
 
+=item * C<pre_eval> (optional)
+
+String with code to pass to eval before each test. For example:
+
+  pre_eval => "no warnings 'redefine';"
+
+Passing the above will silence redefine warnings, but only if you don't set
+warnings subsequently in the test.
+
 =item * C<stats_output> (optional)
 
 C<stats_output> specifies a path where a file will be created to print out
@@ -198,7 +211,7 @@ the output to C</dev/null>, C</tmp> etc).
 This option exist to make the default output format of C<stats_output> be fixed,
 but still allow additions in future versions that will only be written with the
 C<extend_stats> option enabled.
-Additions with C<extend_stats> as of current version:
+Additions with C<extend_stats> as of the current version:
 
 =over 4
 
@@ -343,6 +356,8 @@ sub _run_tests {
             $stats{$test}{timestamp} = _timestamp();
 
             my $result = subtest $iter. "Running test $test" => sub {
+                eval $args->{pre_eval} if $args->{pre_eval};
+
                 $args->{dry_run} ? Test2::V0::ok($test)
                   : $args->{package}
                   ? eval "package Test::$i" . '::' . "$count; do '$test';"
@@ -439,14 +454,14 @@ aggregated together are in different groups.
 In general you can call C<Test2::Aggregate::run_tests> multiple times in a test and
 even load C<run_tests> with tests that already contain another C<run_tests>, the
 only real issue with multiple calls is that if you use C<repeat < 0> on a call,
-C<Test2::Plugin::BailOnFail> is loaded so any subsequent failure, on any following
+L<Test2::Plugin::BailOnFail> is loaded so any subsequent failure, on any following
 C<run_tests> call will trigger a Bail.
 
 =head2 Test::More
 
-If you haven't switched to the C<Test2::Suite> you are generally advised to do so
+If you haven't switched to the L<Test2::Suite> you are generally advised to do so
 for a number of reasons, compatibility with this module being only a very minor
-one. If you are stuck with a C<Test::More> suite, C<Test2::Aggregate> can still
+one. If you are stuck with a L<Test::More> suite, L<Test2::Aggregate> can still
 probably help you more than the similarly-named C<Test::Aggregate...> modules.
 
 Although the module tries to load C<Test2> with minimal imports to not interfere,
@@ -454,7 +469,7 @@ it is generally better to do C<use Test::More;> in your aggregating test (i.e.
 alongside with C<use Test2::Aggregate>.
 
 One more caveat is that C<Test2::Aggregate::run_tests> uses C<subtest> from the
-C<Test2::Suite>, which on rare occasions can return a true value when a C<Test::More>
+L<Test2::Suite>, which on rare occasions can return a true value when a L<Test::More>
 subtest fails by running no tests, so you could have a failed test show up as
 having a 100 C<pass_perc> in the C<Test2::Aggregate::run_tests> output.
 
